==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/PayDriver.pm <==
package WebGUI::i18n::German::PayDriver;
use utf8;
our $I18N = {
  'a sale has been made' => {
    'lastUpdated' => '1240780661',
    'message' => 'Ein Verkauf wurde getätigt. Bestell-Nr: '
  },
  'cart summary variables' => {
    'lastUpdated' => '1273500925',
    'message' => 'Warenkorbzusammenfassung - Variablen'
  },
  'cart summary variables help' => {
    'lastUpdated' => '1273500994',
    'message' => 'Diese Variablen sind in allen PayDriver Templates verfügbar, um die Warenkorbzusammenfassung anzuzeigen.'
  },
  'credit card' => {
    'lastUpdated' => '1234737231',
    'message' => 'Kreditkarte'
  },
  'email receipt template' => {
    'lastUpdated' => '1273501006',
    'message' => 'Vorlage E-Mail Auftragbestätigung/Rechnung'
  },
  'email receipt template help' => {
    'lastUpdated' => '1241166199',
    'message' => 'Vorlage Auftragsbestätigung/Rechnung für den Versand per Email'
  },
  'enabled' => {
    'lastUpdated' => '1234737498',
    'message' => 'Freigegeben'
  },
  'enabled help' => {
    'lastUpdated' => '1241616138',
    'message' => 'Diese Einstellung gibt diese Möglichkeit zur Zahlung frei.'
  },
  'error processing payment' => {
    'lastUpdated' => '1234737617',
    'message' => 'Fehlerbearbeitung Zahlung'
  },
  'error processing payment message' => {
    'lastUpdated' => '1241155701',
    'message' => 'Es gab einen Fehler bei der Verarbeitung Ihrer Zahlung. Gewöhnlich wird das verursacht durch Schreibfehler. Es kann natürlich auch ein Verbindungsproblem sein oder Ihr Konto verfügt nicht über genügende Reserven um diese Transaktion abzuschließen.

Die Fehlermeldung, die wir bekamen wird unten aufgeführt.
Benutzen Sie die "Zurück"-Funktion des Browsers und korrigieren Sie ggf. die Fehler.
Sollten die Fehler nicht behoben werden können, kontaktieren Sie uns bitte.'
  },
  'label' => {
    'lastUpdated' => '1241155711',
    'message' => 'Label'
  },
  'label help' => {
    'lastUpdated' => '1241155799',
    'message' => 'Die Bezeichnung womit diese Zahlungsmethode auf den Bildschirm zu den Zahlungsweisen angezeigt wird.'
  },
  'payment methods' => {
    'lastUpdated' => '1241616177',
    'message' => 'Zahlungsart'
  },
  'proceedButton' => {
    'lastUpdated' => '1273501134',
    'message' => 'Eine Button-Formular-Kombination die der Nutzer anklickt, wenn er die Rechnungsbeträge geprüft hat, die an dieses Bezahl-Gateway übermittelt werden.'
  },
  'receipt email template' => {
    'lastUpdated' => '1241166137',
    'message' => 'Vorlage Emailbeleg (Auftragsbestätigung/Rechnung)'
  },
  'receipt email template help' => {
    'lastUpdated' => '1241166225',
    'message' => 'Welche Vorlage soll verwendet werden für die Auftragsbestätigung/Rechnung per Email?'
  },
  'receipt subject' => {
    'lastUpdated' => '1241166123',
    'message' => 'Auftragbestätigung/Rechnung für Auftrag-Nr'
  },
  'sale notification group' => {
    'lastUpdated' => '1241156129',
    'message' => 'Gruppe für Verkaufsmitteilungen?'
  },
  'sale notification group help' => {
    'lastUpdated' => '1241156157',
    'message' => 'Wer soll informiert werden über neue Transaktionen?'
  },
  'template gone' => {
    'lastUpdated' => '1273501265',
    'message' => 'Das Template zur Eingabe der Zugangsdaten wurde gelöscht, bitte benachrichtigen Sie den Administrator.'
  },
  'try again' => {
    'lastUpdated' => '1241156178',
    'message' => 'Gehen Sie bitte zurück und versuchen Sie es erneut.'
  },
  'who can use' => {
    'lastUpdated' => '1241156196',
    'message' => 'Wer kann dieses Zahlungsart verwenden?'
  },
  'who can use help' => {
    'lastUpdated' => '1241156226',
    'message' => 'Spezifiziert, welche Gruppe diese Zahlunsgart verwenden kann.'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/PayDriver.pm <==
package WebGUI::i18n::German::PayDriver;
use utf8;
our $I18N = {
  'a sale has been made' => {
    'lastUpdated' => '1240780661',
    'message' => 'Ein Verkauf wurde getätigt. Bestell-Nr: '
  },
  'cart summary variables' => {
    'lastUpdated' => '1273500925',
    'message' => 'Warenkorbzusammenfassung - Variablen'
  },
  'cart summary variables help' => {
    'lastUpdated' => '1273500994',
    'message' => 'Diese Variablen sind in allen PayDriver Templates verfügbar, um die Warenkorbzusammenfassung anzuzeigen.'
  },
  'credit card' => {
    'lastUpdated' => '1234737231',
    'message' => 'Kreditkarte'
  },
  'email receipt template' => {
    'lastUpdated' => '1273501006',
    'message' => 'Vorlage E-Mail Auftragbestätigung/Rechnung'
  },
  'email receipt template help' => {
    'lastUpdated' => '1241166199',
    'message' => 'Vorlage Auftragsbestätigung/Rechnung für den Versand per Email'
  },
  'enabled' => {
    'lastUpdated' => '1234737498',
    'message' => 'Freigegeben'
  },
  'enabled help' => {
    'lastUpdated' => '1241616138',
    'message' => 'Diese Einstellung gibt diese Möglichkeit zur Zahlung frei.'
  },
  'error processing payment' => {
    'lastUpdated' => '1234737617',
    'message' => 'Fehlerbearbeitung Zahlung'
  },
  'error processing payment message' => {
    'lastUpdated' => '1241155701',
    'message' => 'Es gab einen Fehler bei der Verarbeitung Ihrer Zahlung. Gewöhnlich wird das verursacht durch Schreibfehler. Es kann natürlich auch ein Verbindungsproblem sein oder Ihr Konto verfügt nicht über genügende Reserven um diese Transaktion abzuschließen.

Die Fehlermeldung, die wir bekamen wird unten aufgeführt.
Benutzen Sie die "Zurück"-Funktion des Browsers und korrigieren Sie ggf. die Fehler.
Sollten die Fehler nicht behoben werden können, kontaktieren Sie uns bitte.'
  },
  'label' => {
    'lastUpdated' => '1241155711',
    'message' => 'Label'
  },
  'label help' => {
    'lastUpdated' => '1241155799',
    'message' => 'Die Bezeichnung womit diese Zahlungsmethode auf den Bildschirm zu den Zahlungsweisen angezeigt wird.'
  },
  'payment methods' => {
    'lastUpdated' => '1241616177',
    'message' => 'Zahlungsart'
  },
  'proceedButton' => {
    'lastUpdated' => '1273501134',
    'message' => 'Eine Button-Formular-Kombination die der Nutzer anklickt, wenn er die Rechnungsbeträge geprüft hat, die an dieses Bezahl-Gateway übermittelt werden.'
  },
  'receipt email template' => {
    'lastUpdated' => '1241166137',
    'message' => 'Vorlage Emailbeleg (Auftragsbestätigung/Rechnung)'
  },
  'receipt email template help' => {
    'lastUpdated' => '1241166225',
    'message' => 'Welche Vorlage soll verwendet werden für die Auftragsbestätigung/Rechnung per Email?'
  },
  'receipt subject' => {
    'lastUpdated' => '1241166123',
    'message' => 'Auftragbestätigung/Rechnung für Auftrag-Nr'
  },
  'sale notification group' => {
    'lastUpdated' => '1241156129',
    'message' => 'Gruppe für Verkaufsmitteilungen?'
  },
  'sale notification group help' => {
    'lastUpdated' => '1241156157',
    'message' => 'Wer soll informiert werden über neue Transaktionen?'
  },
  'template gone' => {
    'lastUpdated' => '1273501265',
    'message' => 'Das Template zur Eingabe der Zugangsdaten wurde gelöscht, bitte benachrichtigen Sie den Administrator.'
  },
  'try again' => {
    'lastUpdated' => '1241156178',
    'message' => 'Gehen Sie bitte zurück und versuchen Sie es erneut.'
  },
  'unable to finish transaction' => {
    'lastUpdated' => '1306299889',
    'message' => 'Wir können die Transaktion nicht aufrufen, um den Bezahlvorgang abzuschließen.'
  },
  'who can use' => {
    'lastUpdated' => '1241156196',
    'message' => 'Wer kann dieses Zahlungsart verwenden?'
  },
  'who can use help' => {
    'lastUpdated' => '1241156226',
    'message' => 'Spezifiziert, welche Gruppe diese Zahlunsgart verwenden kann.'
  }
}
;

1;
